# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/tx_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import export_pb2 as ydb_dot_core_dot_protos_dot_export__pb2
from ydb.core.protos import flat_scheme_op_pb2 as ydb_dot_core_dot_protos_dot_flat__scheme__op__pb2
from ydb.core.protos import issue_id_pb2 as ydb_dot_core_dot_protos_dot_issue__id__pb2
from ydb.core.protos import query_stats_pb2 as ydb_dot_core_dot_protos_dot_query__stats__pb2
from ydb.library.mkql_proto.protos import minikql_pb2 as ydb_dot_library_dot_mkql__proto_dot_protos_dot_minikql__pb2
from ydb.public.api.protos import ydb_issue_message_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__issue__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eydb/core/protos/tx_proxy.proto\x12\x12NKikimrTxUserProxy\x1a\x1cydb/core/protos/export.proto\x1a$ydb/core/protos/flat_scheme_op.proto\x1a\x1eydb/core/protos/issue_id.proto\x1a!ydb/core/protos/query_stats.proto\x1a+ydb/library/mkql_proto/protos/minikql.proto\x1a-ydb/public/api/protos/ydb_issue_message.proto\"\xa5\x03\n\x0eTRWTransaction\x12@\n\tPredicate\x18\x01 \x03(\x0b\x32-.NKikimrTxUserProxy.TRWTransaction.TPredicate\x12\x36\n\x04Read\x18\x02 \x03(\x0b\x32(.NKikimrTxUserProxy.TRWTransaction.TRead\x12\x38\n\x05Write\x18\x03 \x03(\x0b\x32).NKikimrTxUserProxy.TRWTransaction.TWrite\x1a\x64\n\nTPredicate\x12\x0b\n\x03Key\x18\x01 \x01(\x0c\x12\r\n\x05Value\x18\x02 \x01(\x0c\x12\x11\n\tValueType\x18\x03 \x01(\r\x12\x14\n\x0cMustNotExist\x18\x04 \x01(\x08\x12\x11\n\tMustExist\x18\x05 \x01(\x08\x1a\x31\n\x05TRead\x12\x0b\n\x03Key\x18\x01 \x01(\x0c\x12\x1b\n\x13\x45xpectedPayloadType\x18\n \x01(\r\x1a\x46\n\x06TWrite\x12\x0b\n\x03Key\x18\x01 \x01(\x0c\x12\r\n\x05Value\x18\x02 \x01(\x0c\x12\x11\n\tValueType\x18\x03 \x01(\r\x12\r\n\x05\x45rase\x18\x04 \x01(\x08\"f\n\x10TReadTransaction\x12\x0e\n\x06StepId\x18\x02 \x01(\x06\x12\x0f\n\x07OrderId\x18\x03 \x01(\x06\x1a\x31\n\x05TRead\x12\x0b\n\x03Key\x18\x01 \x01(\x0c\x12\x1b\n\x13\x45xpectedPayloadType\x18\n \x01(\r\"\x90\x01\n\tTKeyRange\x12%\n\x04\x46rom\x18\x01 \x01(\x0b\x32\x17.NKikimrMiniKQL.TParams\x12#\n\x02To\x18\x02 \x01(\x0b\x32\x17.NKikimrMiniKQL.TParams\x12\x1b\n\rFromInclusive\x18\x03 \x01(\x08:\x04true\x12\x1a\n\x0bToInclusive\x18\x04 \x01(\x08:\x05\x66\x61lse\"\x9d\x02\n\x15TReadTableTransaction\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x16\n\x07Ordered\x18\x02 \x01(\x08:\x05\x66\x61lse\x12\x1e\n\x0f\x41llowDuplicates\x18\x03 \x01(\x08:\x05\x66\x61lse\x12\x0f\n\x07\x43olumns\x18\x04 \x03(\t\x12/\n\x08KeyRange\x18\x05 \x01(\x0b\x32\x1d.NKikimrTxUserProxy.TKeyRange\x12\x13\n\x08RowLimit\x18\x06 \x01(\x04:\x01\x30\x12\x12\n\nApiVersion\x18\x07 \x01(\r\x12\x14\n\x0cSnapshotStep\x18\x08 \x01(\x04\x12\x14\n\x0cSnapshotTxId\x18\t \x01(\x04\"\'\n\x08\x45Version\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\n\n\x06YDB_V1\x10\x01\"\xeb\x01\n\x19TCreateVolatileSnapshotTx\x12\x44\n\x06Tables\x18\x01 \x03(\x0b\x32\x34.NKikimrTxUserProxy.TCreateVolatileSnapshotTx.TTable\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x11\n\tTimeoutMs\x18\x03 \x01(\x04\x12\x19\n\x11IgnoreSystemViews\x18\x04 \x01(\x08\x1aL\n\x06TTable\x12\x11\n\tTablePath\x18\x01 \x01(\t\x12/\n\x08KeyRange\x18\x02 \x01(\x0b\x32\x1d.NKikimrTxUserProxy.TKeyRange\"\xf8\x01\n\x1aTRefreshVolatileSnapshotTx\x12\x45\n\x06Tables\x18\x01 \x03(\x0b\x32\x35.NKikimrTxUserProxy.TRefreshVolatileSnapshotTx.TTable\x12\x14\n\x0cSnapshotStep\x18\x02 \x01(\x04\x12\x14\n\x0cSnapshotTxId\x18\x03 \x01(\x04\x12\x19\n\x11IgnoreSystemViews\x18\x04 \x01(\x08\x1aL\n\x06TTable\x12\x11\n\tTablePath\x18\x01 \x01(\t\x12/\n\x08KeyRange\x18\x02 \x01(\x0b\x32\x1d.NKikimrTxUserProxy.TKeyRange\"\xf8\x01\n\x1aTDiscardVolatileSnapshotTx\x12\x45\n\x06Tables\x18\x01 \x03(\x0b\x32\x35.NKikimrTxUserProxy.TDiscardVolatileSnapshotTx.TTable\x12\x14\n\x0cSnapshotStep\x18\x02 \x01(\x04\x12\x14\n\x0cSnapshotTxId\x18\x03 \x01(\x04\x12\x19\n\x11IgnoreSystemViews\x18\x04 \x01(\x08\x1aL\n\x06TTable\x12\x11\n\tTablePath\x18\x01 \x01(\t\x12/\n\x08KeyRange\x18\x02 \x01(\x0b\x32\x1d.NKikimrTxUserProxy.TKeyRange\"\xae\x01\n\x0fTCommitWritesTx\x12:\n\x06Tables\x18\x01 \x03(\x0b\x32*.NKikimrTxUserProxy.TCommitWritesTx.TTable\x12\x11\n\tWriteTxId\x18\x02 \x01(\x04\x1aL\n\x06TTable\x12\x11\n\tTablePath\x18\x01 \x01(\t\x12/\n\x08KeyRange\x18\x02 \x01(\x0b\x32\x1d.NKikimrTxUserProxy.TKeyRange\"\xe1\x06\n\x13TMiniKQLTransaction\x12M\n\x04Mode\x18\x01 \x01(\x0e\x32-.NKikimrTxUserProxy.TMiniKQLTransaction.EMode:\x10\x43OMPILE_AND_EXEC\x12H\n\x07Program\x18\x02 \x01(\x0b\x32\x37.NKikimrTxUserProxy.TMiniKQLTransaction.TMiniKQLProgram\x12\x46\n\x06Params\x18\x03 \x01(\x0b\x32\x36.NKikimrTxUserProxy.TMiniKQLTransaction.TMiniKQLParams\x12 \n\x12\x45valuateResultType\x18\x32 \x01(\x08:\x04true\x12!\n\x13\x45valuateResultValue\x18\x33 \x01(\x08:\x04true\x12\x16\n\x08\x46latMKQL\x18\x34 \x01(\x08:\x04true\x12\x13\n\x0bLlvmRuntime\x18\x35 \x01(\x08\x12\"\n\x1aPerShardKeysSizeLimitBytes\x18\x36 \x01(\x04\x12\x14\n\x0c\x43ollectStats\x18\x37 \x01(\x08\x12?\n\x06Limits\x18\x38 \x01(\x0b\x32/.NKikimrTxUserProxy.TMiniKQLTransaction.TLimits\x12\x14\n\x0cSnapshotStep\x18\t \x01(\x04\x12\x14\n\x0cSnapshotTxId\x18\n \x01(\x04\x1a\x45\n\x0fTMiniKQLProgram\x12\x0c\n\x04Text\x18\x01 \x01(\t\x12\x0b\n\x03\x42in\x18\x02 \x01(\x0c\x12\x17\n\x0fResultDocScheme\x18\x03 \x01(\x0c\x1aS\n\x0eTMiniKQLParams\x12\x0c\n\x04Text\x18\x01 \x01(\t\x12\x0b\n\x03\x42in\x18\x02 \x01(\x0c\x12&\n\x05Proto\x18\x03 \x01(\x0b\x32\x17.NKikimrMiniKQL.TParams\x1a\x87\x01\n\x07TLimits\x12\x1b\n\x13\x41\x66\x66\x65\x63tedShardsLimit\x18\x01 \x01(\r\x12\x19\n\x11ReadsetCountLimit\x18\x02 \x01(\r\x12#\n\x1b\x43omputeNodeMemoryLimitBytes\x18\x03 \x01(\x04\x12\x1f\n\x17TotalReadSizeLimitBytes\x18\x04 \x01(\x04\"*\n\x05\x45Mode\x12\x14\n\x10\x43OMPILE_AND_EXEC\x10\x01\x12\x0b\n\x07\x43OMPILE\x10\x02\"\xb6\x01\n\x16TMiniKQLCompileResults\x12\x17\n\x0f\x43ompiledProgram\x18\x01 \x01(\x0c\x12\x35\n\x14ProgramCompileErrors\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x16\n\x0e\x43ompiledParams\x18\x14 \x01(\x0c\x12\x34\n\x13ParamsCompileErrors\x18\x15 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"\xe7\x04\n\x0cTTransaction\x12\x43\n\x12MiniKQLTransaction\x18\x04 \x01(\x0b\x32\'.NKikimrTxUserProxy.TMiniKQLTransaction\x12\r\n\x05\x46lags\x18\x06 \x01(\r\x12\x15\n\rUserRequestId\x18\x08 \x01(\t\x12\x34\n\x0cModifyScheme\x18\n \x01(\x0b\x32\x1e.NKikimrSchemeOp.TModifyScheme\x12\x41\n\x19TransactionalModification\x18\x0b \x03(\x0b\x32\x1e.NKikimrSchemeOp.TModifyScheme\x12G\n\x14ReadTableTransaction\x18\x14 \x01(\x0b\x32).NKikimrTxUserProxy.TReadTableTransaction\x12M\n\x16\x43reateVolatileSnapshot\x18\x1e \x01(\x0b\x32-.NKikimrTxUserProxy.TCreateVolatileSnapshotTx\x12O\n\x17RefreshVolatileSnapshot\x18\x1f \x01(\x0b\x32..NKikimrTxUserProxy.TRefreshVolatileSnapshotTx\x12O\n\x17\x44iscardVolatileSnapshot\x18  \x01(\x0b\x32..NKikimrTxUserProxy.TDiscardVolatileSnapshotTx\x12\x39\n\x0c\x43ommitWrites\x18( \x01(\x0b\x32#.NKikimrTxUserProxy.TCommitWritesTx\"\xea\x01\n\x15TEvProposeTransaction\x12\x35\n\x0bTransaction\x18\x01 \x01(\x0b\x32 .NKikimrTxUserProxy.TTransaction\x12\x12\n\nProxyFlags\x18\x02 \x01(\x04\x12\x19\n\x11\x45xecTimeoutPeriod\x18\x03 \x01(\x04\x12\x11\n\tUserToken\x18\x04 \x01(\t\x12\x16\n\x0eStreamResponse\x18\x05 \x01(\x08\x12\x15\n\rCancelAfterMs\x18\x06 \x01(\x04\x12\x14\n\x0c\x44\x61tabaseName\x18\x07 \x01(\t\x12\x13\n\x0bRequestType\x18\x08 \x01(\t\"\x84\x02\n\x0fTTxProxyTimings\x12\x19\n\x11WallClockAccepted\x18\n \x01(\x04\x12\x19\n\x11WallClockResolved\x18\x0b \x01(\x04\x12\x19\n\x11WallClockPrepared\x18\x0c \x01(\x04\x12\x18\n\x10WallClockPlanned\x18\r \x01(\x04\x12\x14\n\x0cWallClockNow\x18\x0e \x01(\x04\x12\x1a\n\x12\x45lapsedPrepareExec\x18\x0f \x01(\x04\x12\x17\n\x0f\x45lapsedExecExec\x18\x10 \x01(\x04\x12\x1e\n\x16\x45lapsedPrepareComplete\x18\x11 \x01(\x04\x12\x1b\n\x13\x45lapsedExecComplete\x18\x12 \x01(\x04\"\x99\x07\n\x1bTEvProposeTransactionStatus\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x0c\n\x04TxId\x18\x02 \x01(\x06\x12\x0c\n\x04Step\x18\x03 \x01(\x06\x12\x39\n\nStatusCode\x18\x07 \x01(\x0e\x32%.NKikimrIssues.TStatusIds.EStatusCode\x12\'\n\x06Issues\x18\x08 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x1d\n\x15\x45xecutionEngineStatus\x18\n \x01(\r\x12%\n\x1d\x45xecutionEngineResponseStatus\x18\x0b \x01(\r\x12\x1f\n\x17\x45xecutionEngineResponse\x18\x0c \x01(\x0c\x12\x15\n\rMiniKQLErrors\x18\r \x01(\x0c\x12\x17\n\x0f\x44\x61taShardErrors\x18\x0e \x01(\x0c\x12\x1d\n\x15\x43omplainingDataShards\x18\x0f \x03(\x06\x12\x16\n\x0eUnresolvedKeys\x18\x10 \x03(\x0c\x12I\n\x15MiniKQLCompileResults\x18\x11 \x01(\x0b\x32*.NKikimrTxUserProxy.TMiniKQLCompileResults\x12\x41\n ExecutionEngineEvaluatedResponse\x18\x12 \x01(\x0b\x32\x17.NKikimrMiniKQL.TResult\x12,\n\x07TxStats\x18\x13 \x01(\x0b\x32\x1b.NKikimrQueryStats.TTxStats\x12\x34\n\x07Timings\x18\x14 \x01(\x0b\x32#.NKikimrTxUserProxy.TTxProxyTimings\x12\x18\n\x10HadFollowerReads\x18\x15 \x01(\x08\x12\x19\n\x11SchemeShardStatus\x18\x1e \x01(\r\x12\x1d\n\x15SchemeShardReportedId\x18\x1f \x01(\r\x12\x19\n\x11SchemeShardReason\x18  \x01(\x0c\x12\x1b\n\x13SchemeShardTabletId\x18! \x01(\x06\x12\x0e\n\x06PathId\x18\" \x01(\x04\x12\x16\n\x0ePathCreateTxId\x18# \x01(\x04\x12\x14\n\x0cPathDropTxId\x18$ \x01(\x04\x12\x19\n\x11\x44\x61taShardTabletId\x18( \x01(\x06\x12#\n\x1bSerializedReadTableResponse\x18\x32 \x01(\x0c\x12 \n\x18ReadTableResponseVersion\x18\x33 \x01(\r\"\x84\x01\n\x0bTEvNavigate\x12\x34\n\x0c\x44\x65scribePath\x18\x05 \x01(\x0b\x32\x1e.NKikimrSchemeOp.TDescribePath\x12\x11\n\tUserToken\x18\x06 \x01(\t\x12\x14\n\x0c\x44\x61tabaseName\x18\x07 \x01(\tJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05\"\xce\x01\n\x1cTEvNavigateStatus_Deprecated\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x14\n\x0cSchemePrefix\x18\n \x01(\x0c\x12\x12\n\nSchemePart\x18\x0b \x01(\x0c\x12\x19\n\x11SchemeShardStatus\x18\x1e \x01(\r\x12\x1d\n\x15SchemeShardReportedId\x18\x1f \x01(\r\x12:\n\x0fPathDescription\x18( \x01(\x0b\x32!.NKikimrSchemeOp.TPathDescription\"<\n\x12TEvInvalidateTable\x12\x15\n\rSchemeShardId\x18\x01 \x01(\x04\x12\x0f\n\x07TableId\x18\x02 \x01(\x04\"\xef\x02\n\x10TEvExportRequest\x12\x14\n\x0c\x44\x61tabaseName\x18\x01 \x01(\t\x12\x11\n\tUserToken\x18\x02 \x01(\t\x12;\n\x0c\x43reateExport\x18\x03 \x01(\x0b\x32#.NKikimrExport.TCreateExportRequestH\x00\x12\x35\n\tGetExport\x18\x04 \x01(\x0b\x32 .NKikimrExport.TGetExportRequestH\x00\x12;\n\x0c\x43\x61ncelExport\x18\x05 \x01(\x0b\x32#.NKikimrExport.TCancelExportRequestH\x00\x12;\n\x0c\x46orgetExport\x18\x06 \x01(\x0b\x32#.NKikimrExport.TForgetExportRequestH\x00\x12\x39\n\x0bListExports\x18\x07 \x01(\x0b\x32\".NKikimrExport.TListExportsRequestH\x00\x42\t\n\x07Request\"\xf7\x02\n\x11TEvExportResponse\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x18\n\x10\x45rrorDescription\x18\x07 \x01(\t\x12<\n\x0c\x43reateExport\x18\x02 \x01(\x0b\x32$.NKikimrExport.TCreateExportResponseH\x00\x12\x36\n\tGetExport\x18\x03 \x01(\x0b\x32!.NKikimrExport.TGetExportResponseH\x00\x12<\n\x0c\x43\x61ncelExport\x18\x04 \x01(\x0b\x32$.NKikimrExport.TCancelExportResponseH\x00\x12<\n\x0c\x46orgetExport\x18\x05 \x01(\x0b\x32$.NKikimrExport.TForgetExportResponseH\x00\x12:\n\x0bListExports\x18\x06 \x01(\x0b\x32#.NKikimrExport.TListExportsResponseH\x00\x42\n\n\x08ResponseB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.tx_proxy_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TRWTRANSACTION._serialized_start=282
  _TRWTRANSACTION._serialized_end=703
  _TRWTRANSACTION_TPREDICATE._serialized_start=480
  _TRWTRANSACTION_TPREDICATE._serialized_end=580
  _TRWTRANSACTION_TREAD._serialized_start=582
  _TRWTRANSACTION_TREAD._serialized_end=631
  _TRWTRANSACTION_TWRITE._serialized_start=633
  _TRWTRANSACTION_TWRITE._serialized_end=703
  _TREADTRANSACTION._serialized_start=705
  _TREADTRANSACTION._serialized_end=807
  _TREADTRANSACTION_TREAD._serialized_start=582
  _TREADTRANSACTION_TREAD._serialized_end=631
  _TKEYRANGE._serialized_start=810
  _TKEYRANGE._serialized_end=954
  _TREADTABLETRANSACTION._serialized_start=957
  _TREADTABLETRANSACTION._serialized_end=1242
  _TREADTABLETRANSACTION_EVERSION._serialized_start=1203
  _TREADTABLETRANSACTION_EVERSION._serialized_end=1242
  _TCREATEVOLATILESNAPSHOTTX._serialized_start=1245
  _TCREATEVOLATILESNAPSHOTTX._serialized_end=1480
  _TCREATEVOLATILESNAPSHOTTX_TTABLE._serialized_start=1404
  _TCREATEVOLATILESNAPSHOTTX_TTABLE._serialized_end=1480
  _TREFRESHVOLATILESNAPSHOTTX._serialized_start=1483
  _TREFRESHVOLATILESNAPSHOTTX._serialized_end=1731
  _TREFRESHVOLATILESNAPSHOTTX_TTABLE._serialized_start=1404
  _TREFRESHVOLATILESNAPSHOTTX_TTABLE._serialized_end=1480
  _TDISCARDVOLATILESNAPSHOTTX._serialized_start=1734
  _TDISCARDVOLATILESNAPSHOTTX._serialized_end=1982
  _TDISCARDVOLATILESNAPSHOTTX_TTABLE._serialized_start=1404
  _TDISCARDVOLATILESNAPSHOTTX_TTABLE._serialized_end=1480
  _TCOMMITWRITESTX._serialized_start=1985
  _TCOMMITWRITESTX._serialized_end=2159
  _TCOMMITWRITESTX_TTABLE._serialized_start=1404
  _TCOMMITWRITESTX_TTABLE._serialized_end=1480
  _TMINIKQLTRANSACTION._serialized_start=2162
  _TMINIKQLTRANSACTION._serialized_end=3027
  _TMINIKQLTRANSACTION_TMINIKQLPROGRAM._serialized_start=2691
  _TMINIKQLTRANSACTION_TMINIKQLPROGRAM._serialized_end=2760
  _TMINIKQLTRANSACTION_TMINIKQLPARAMS._serialized_start=2762
  _TMINIKQLTRANSACTION_TMINIKQLPARAMS._serialized_end=2845
  _TMINIKQLTRANSACTION_TLIMITS._serialized_start=2848
  _TMINIKQLTRANSACTION_TLIMITS._serialized_end=2983
  _TMINIKQLTRANSACTION_EMODE._serialized_start=2985
  _TMINIKQLTRANSACTION_EMODE._serialized_end=3027
  _TMINIKQLCOMPILERESULTS._serialized_start=3030
  _TMINIKQLCOMPILERESULTS._serialized_end=3212
  _TTRANSACTION._serialized_start=3215
  _TTRANSACTION._serialized_end=3830
  _TEVPROPOSETRANSACTION._serialized_start=3833
  _TEVPROPOSETRANSACTION._serialized_end=4067
  _TTXPROXYTIMINGS._serialized_start=4070
  _TTXPROXYTIMINGS._serialized_end=4330
  _TEVPROPOSETRANSACTIONSTATUS._serialized_start=4333
  _TEVPROPOSETRANSACTIONSTATUS._serialized_end=5254
  _TEVNAVIGATE._serialized_start=5257
  _TEVNAVIGATE._serialized_end=5389
  _TEVNAVIGATESTATUS_DEPRECATED._serialized_start=5392
  _TEVNAVIGATESTATUS_DEPRECATED._serialized_end=5598
  _TEVINVALIDATETABLE._serialized_start=5600
  _TEVINVALIDATETABLE._serialized_end=5660
  _TEVEXPORTREQUEST._serialized_start=5663
  _TEVEXPORTREQUEST._serialized_end=6030
  _TEVEXPORTRESPONSE._serialized_start=6033
  _TEVEXPORTRESPONSE._serialized_end=6408
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2
from ydb.core.protos import base_pb2 as ydb_dot_core_dot_protos_dot_base__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18ydb/core/protos/tx.proto\x12\tNKikimrTx\x1a&library/cpp/actors/protos/actors.proto\x1a\x1aydb/core/protos/base.proto\x1a\x19google/protobuf/any.proto\"\xe7\x01\n\x11TProxyTransaction\x12@\n\x0b\x41\x66\x66\x65\x63tedSet\x18\x01 \x03(\x0b\x32+.NKikimrTx.TProxyTransaction.TAffectedEntry\x12\x11\n\tExecLevel\x18\x03 \x01(\r\x12\x0c\n\x04TxId\x18\x04 \x01(\x06\x12\x0f\n\x07MinStep\x18\x06 \x01(\x04\x12\x0f\n\x07MaxStep\x18\x07 \x01(\x04\x12\x1a\n\x12IgnoreLowDiskSpace\x18\x08 \x01(\x08\x1a\x31\n\x0eTAffectedEntry\x12\x10\n\x08TabletId\x18\x01 \x01(\x06\x12\r\n\x05\x46lags\x18\x02 \x01(\r\"a\n\x15TEvProposeTransaction\x12\x31\n\x0bTransaction\x18\x01 \x01(\x0b\x32\x1c.NKikimrTx.TProxyTransaction\x12\x15\n\rCoordinatorID\x18\n \x01(\x06\"K\n\x1bTEvProposeTransactionStatus\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x0e\n\x06StepId\x18\x02 \x01(\x06\x12\x0c\n\x04TxId\x18\t \x01(\x06\"+\n\x12TEvAcquireReadStep\x12\x15\n\rCoordinatorID\x18\x01 \x01(\x06\"?\n\x18TEvAcquireReadStepResult\x12\x15\n\rCoordinatorID\x18\x01 \x01(\x06\x12\x0c\n\x04Step\x18\x02 \x01(\x06\"<\n\x14TEvSubscribeReadStep\x12\x15\n\rCoordinatorID\x18\x01 \x01(\x06\x12\r\n\x05SeqNo\x18\x02 \x01(\x04\">\n\x16TEvUnsubscribeReadStep\x12\x15\n\rCoordinatorID\x18\x01 \x01(\x06\x12\r\n\x05SeqNo\x18\x02 \x01(\x04\"t\n\x1aTEvSubscribeReadStepResult\x12\x15\n\rCoordinatorID\x18\x01 \x01(\x06\x12\r\n\x05SeqNo\x18\x02 \x01(\x04\x12\x17\n\x0fLastAcquireStep\x18\x03 \x01(\x06\x12\x17\n\x0fNextAcquireStep\x18\x04 \x01(\x06\"[\n\x1aTEvSubscribeReadStepUpdate\x12\x15\n\rCoordinatorID\x18\x01 \x01(\x06\x12\r\n\x05SeqNo\x18\x02 \x01(\x04\x12\x17\n\x0fNextAcquireStep\x18\x03 \x01(\x06\"]\n\x17TCoordinatorTransaction\x12\x13\n\x0b\x41\x66\x66\x65\x63tedSet\x18\x01 \x03(\x04\x12\x0c\n\x04TxId\x18\x02 \x01(\x06\x12\x0c\n\x04\x42ody\x18\x03 \x01(\x0c\x12\x11\n\tModerator\x18\x05 \x01(\x04\"\xa4\x01\n\x1cTEvSubDomainConfigurationAck\x12?\n\x06Status\x18\x01 \x01(\x0e\x32/.NKikimrTx.TEvSubDomainConfigurationAck.EStatus\x12\x12\n\nOnTabletId\x18\x02 \x01(\x06\"/\n\x07\x45Status\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0b\n\x07\x41LREADY\x10\x01\x12\n\n\x06REJECT\x10\x02\"O\n\x12TEvCoordinatorSync\x12\x0e\n\x06\x43ookie\x18\x01 \x01(\x06\x12\x12\n\nMediatorID\x18\t \x01(\x06\x12\x15\n\rCoordinatorID\x18\n \x01(\x06\"\xc4\x01\n\x18TEvCoordinatorSyncResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x0e\n\x06\x43ookie\x18\x02 \x01(\x06\x12\x14\n\x0c\x43ompleteStep\x18\x03 \x01(\x06\x12\x13\n\x0bLatestKnown\x18\x04 \x01(\x06\x12\x16\n\x0eSubjectiveTime\x18\x05 \x01(\x06\x12\x12\n\nMediatorID\x18\t \x01(\x06\x12\x15\n\rCoordinatorID\x18\n \x01(\x06\"\xde\x01\n\x12TEvCoordinatorStep\x12\x38\n\x0cTransactions\x18\x01 \x03(\x0b\x32\".NKikimrTx.TCoordinatorTransaction\x12\x0c\n\x04Step\x18\x02 \x01(\x06\x12\x10\n\x08PrevStep\x18\x03 \x01(\x06\x12\x12\n\nMediatorID\x18\t \x01(\x06\x12\x15\n\rCoordinatorID\x18\n \x01(\x06\x12#\n\x1b\x41\x63tiveCoordinatorGeneration\x18\x0b \x01(\x04\x12\x1e\n\x16TotalTxAffectedEntries\x18\x14 \x01(\x04\"\"\n\rTEvTxAllocate\x12\x11\n\tRangeSize\x18\x01 \x01(\x06\"\x9a\x01\n\x13TEvTxAllocateResult\x12\x36\n\x06Status\x18\x01 \x01(\x0e\x32&.NKikimrTx.TEvTxAllocateResult.EStatus\x12\x12\n\nRangeBegin\x18\x02 \x01(\x06\x12\x10\n\x08RangeEnd\x18\x03 \x01(\x06\"%\n\x07\x45Status\x12\x0b\n\x07SUCCESS\x10\x00\x12\r\n\tIMPOSIBLE\x10\x01\"\xd1\x02\n\x18TEvCoordinatorStepResult\x12;\n\x06Status\x18\x01 \x01(\x0e\x32+.NKikimrTx.TEvCoordinatorStepResult.EStatus\x12\x0c\n\x04Step\x18\x02 \x01(\x06\x12\x14\n\x0c\x43ompleteStep\x18\x03 \x01(\x06\x12\x13\n\x0bLatestKnown\x18\x04 \x01(\x06\x12\x16\n\x0eSubjectiveTime\x18\x05 \x01(\x06\x12\x12\n\nMediatorID\x18\t \x01(\x06\x12\x15\n\rCoordinatorID\x18\n \x01(\x06\"|\n\x07\x45Status\x12\x17\n\x13UNKNOWN_COORDINATOR\x10\x00\x12\x13\n\x0f\x41\x43\x43\x45PTED_DOMAIN\x10\x01\x12\x14\n\x10\x41\x43\x43\x45PTED_FOREIGN\x10\x02\x12\x15\n\x11\x44ISCARDED_TOOLATE\x10\x03\x12\x16\n\x12\x44ISCARDED_TOOEARLY\x10\x04\">\n\x0eTEvPlanStepAck\x12\x10\n\x08TabletId\x18\x01 \x01(\x06\x12\x0c\n\x04Step\x18\x02 \x01(\x06\x12\x0c\n\x04TxId\x18\x03 \x03(\x06\"5\n\x13TEvPlanStepAccepted\x12\x10\n\x08TabletId\x18\x01 \x01(\x06\x12\x0c\n\x04Step\x18\x02 \x01(\x06\"\x81\x01\n\x14TMediatorTransaction\x12\x0c\n\x04TxId\x18\x01 \x01(\x06\x12\x13\n\x0b\x43oordinator\x18\x02 \x01(\x06\x12\x11\n\tModerator\x18\x03 \x01(\x06\x12\x0c\n\x04\x42ody\x18\x04 \x01(\x0c\x12%\n\x05\x41\x63kTo\x18\n \x01(\x0b\x32\x16.NActorsProto.TActorId\"\x80\x01\n\x13TEvMediatorPlanStep\x12\x35\n\x0cTransactions\x18\x01 \x03(\x0b\x32\x1f.NKikimrTx.TMediatorTransaction\x12\x0c\n\x04Step\x18\x02 \x01(\x04\x12\x12\n\nMediatorID\x18\t \x01(\x06\x12\x10\n\x08TabletID\x18\n \x01(\x06\"g\n\x19TEvTransactionBatchResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x0c\n\x04Step\x18\x02 \x01(\x04\x12\x10\n\x08TabletID\x18\n \x01(\x04\"3\n\x0fTEvMediatorDone\x12\x0c\n\x04Step\x18\x01 \x01(\x04\x12\x12\n\nMediatorID\x18\n \x01(\x04\"\x17\n\x15TEvMediatorDoneResult\"-\n\x0bTBalanceHop\x12\r\n\x05Shard\x18\x01 \x01(\x04\x12\x0f\n\x07Sibling\x18\x02 \x03(\x04\"4\n\rTBalanceTrack\x12#\n\x03Hop\x18\x01 \x03(\x0b\x32\x16.NKikimrTx.TBalanceHop\"<\n\x11TBalanceTrackList\x12\'\n\x05Track\x18\x01 \x03(\x0b\x32\x18.NKikimrTx.TBalanceTrack\"\xb3\x01\n\x0cTReadSetData\x12\x33\n\x08\x44\x65\x63ision\x18\x01 \x01(\x0e\x32!.NKikimrTx.TReadSetData.EDecision\x12\"\n\x04\x44\x61ta\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\"J\n\tEDecision\x12\x14\n\x10\x44\x45\x43ISION_UNKNOWN\x10\x00\x12\x13\n\x0f\x44\x45\x43ISION_COMMIT\x10\x01\x12\x12\n\x0e\x44\x45\x43ISION_ABORT\x10\x02\"\x97\x02\n\nTEvReadSet\x12\x0c\n\x04Step\x18\x01 \x01(\x04\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\x12\x14\n\x0cTabletSource\x18\x03 \x01(\x04\x12\x12\n\nTabletDest\x18\x04 \x01(\x04\x12\x16\n\x0eTabletProducer\x18\x05 \x01(\x04\x12\x0f\n\x07ReadSet\x18\x06 \x01(\x0c\x12\x36\n\x10\x42\x61lanceTrackList\x18\x07 \x01(\x0b\x32\x1c.NKikimrTx.TBalanceTrackList\x12\r\n\x05Seqno\x18\x08 \x01(\x04\x12\r\n\x05\x46lags\x18\t \x01(\r\"D\n\x06\x45\x46lags\x12\x0f\n\x0b\x46LAG_NO_ACK\x10\x01\x12\x10\n\x0c\x46LAG_NO_DATA\x10\x02\x12\x17\n\x13\x46LAG_EXPECT_READSET\x10\x04\"\x8b\x01\n\rTEvReadSetAck\x12\x0c\n\x04Step\x18\x01 \x01(\x04\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\x12\x14\n\x0cTabletSource\x18\x03 \x01(\x04\x12\x12\n\nTabletDest\x18\x04 \x01(\x04\x12\x16\n\x0eTabletConsumer\x18\x05 \x01(\x04\x12\r\n\x05\x46lags\x18\x06 \x01(\r\x12\r\n\x05Seqno\x18\x07 \x01(\x04\"Q\n\tTKeyRange\x12\x0c\n\x04\x46rom\x18\x01 \x01(\x0c\x12\n\n\x02To\x18\x02 \x01(\x0c\x12\x15\n\rFromInclusive\x18\x03 \x01(\x08\x12\x13\n\x0bToInclusive\x18\x04 \x01(\x08\"b\n\x19TEvStreamClearanceRequest\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x0f\n\x07ShardId\x18\x02 \x01(\x04\x12&\n\x08KeyRange\x18\x03 \x01(\x0b\x32\x14.NKikimrTx.TKeyRange\";\n\x1aTEvStreamClearanceResponse\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x0f\n\x07\x43leared\x18\x02 \x01(\x08\")\n\x19TEvStreamClearancePending\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\"6\n\x15TEvStreamQuotaRequest\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x0f\n\x07ShardId\x18\x02 \x01(\x04\"l\n\x16TEvStreamQuotaResponse\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x18\n\x10MessageSizeLimit\x18\x02 \x01(\x04\x12\x18\n\x10ReservedMessages\x18\x03 \x01(\r\x12\x10\n\x08RowLimit\x18\x04 \x01(\x04\"6\n\x15TEvStreamQuotaRelease\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x0f\n\x07ShardId\x18\x02 \x01(\x04\"\x1f\n\x0fTEvStreamIsDead\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\"\'\n\x17TEvInterruptTransaction\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\"\x12\n\x10TEvStreamDataAckB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TPROXYTRANSACTION._serialized_start=135
  _TPROXYTRANSACTION._serialized_end=366
  _TPROXYTRANSACTION_TAFFECTEDENTRY._serialized_start=317
  _TPROXYTRANSACTION_TAFFECTEDENTRY._serialized_end=366
  _TEVPROPOSETRANSACTION._serialized_start=368
  _TEVPROPOSETRANSACTION._serialized_end=465
  _TEVPROPOSETRANSACTIONSTATUS._serialized_start=467
  _TEVPROPOSETRANSACTIONSTATUS._serialized_end=542
  _TEVACQUIREREADSTEP._serialized_start=544
  _TEVACQUIREREADSTEP._serialized_end=587
  _TEVACQUIREREADSTEPRESULT._serialized_start=589
  _TEVACQUIREREADSTEPRESULT._serialized_end=652
  _TEVSUBSCRIBEREADSTEP._serialized_start=654
  _TEVSUBSCRIBEREADSTEP._serialized_end=714
  _TEVUNSUBSCRIBEREADSTEP._serialized_start=716
  _TEVUNSUBSCRIBEREADSTEP._serialized_end=778
  _TEVSUBSCRIBEREADSTEPRESULT._serialized_start=780
  _TEVSUBSCRIBEREADSTEPRESULT._serialized_end=896
  _TEVSUBSCRIBEREADSTEPUPDATE._serialized_start=898
  _TEVSUBSCRIBEREADSTEPUPDATE._serialized_end=989
  _TCOORDINATORTRANSACTION._serialized_start=991
  _TCOORDINATORTRANSACTION._serialized_end=1084
  _TEVSUBDOMAINCONFIGURATIONACK._serialized_start=1087
  _TEVSUBDOMAINCONFIGURATIONACK._serialized_end=1251
  _TEVSUBDOMAINCONFIGURATIONACK_ESTATUS._serialized_start=1204
  _TEVSUBDOMAINCONFIGURATIONACK_ESTATUS._serialized_end=1251
  _TEVCOORDINATORSYNC._serialized_start=1253
  _TEVCOORDINATORSYNC._serialized_end=1332
  _TEVCOORDINATORSYNCRESULT._serialized_start=1335
  _TEVCOORDINATORSYNCRESULT._serialized_end=1531
  _TEVCOORDINATORSTEP._serialized_start=1534
  _TEVCOORDINATORSTEP._serialized_end=1756
  _TEVTXALLOCATE._serialized_start=1758
  _TEVTXALLOCATE._serialized_end=1792
  _TEVTXALLOCATERESULT._serialized_start=1795
  _TEVTXALLOCATERESULT._serialized_end=1949
  _TEVTXALLOCATERESULT_ESTATUS._serialized_start=1912
  _TEVTXALLOCATERESULT_ESTATUS._serialized_end=1949
  _TEVCOORDINATORSTEPRESULT._serialized_start=1952
  _TEVCOORDINATORSTEPRESULT._serialized_end=2289
  _TEVCOORDINATORSTEPRESULT_ESTATUS._serialized_start=2165
  _TEVCOORDINATORSTEPRESULT_ESTATUS._serialized_end=2289
  _TEVPLANSTEPACK._serialized_start=2291
  _TEVPLANSTEPACK._serialized_end=2353
  _TEVPLANSTEPACCEPTED._serialized_start=2355
  _TEVPLANSTEPACCEPTED._serialized_end=2408
  _TMEDIATORTRANSACTION._serialized_start=2411
  _TMEDIATORTRANSACTION._serialized_end=2540
  _TEVMEDIATORPLANSTEP._serialized_start=2543
  _TEVMEDIATORPLANSTEP._serialized_end=2671
  _TEVTRANSACTIONBATCHRESULT._serialized_start=2673
  _TEVTRANSACTIONBATCHRESULT._serialized_end=2776
  _TEVMEDIATORDONE._serialized_start=2778
  _TEVMEDIATORDONE._serialized_end=2829
  _TEVMEDIATORDONERESULT._serialized_start=2831
  _TEVMEDIATORDONERESULT._serialized_end=2854
  _TBALANCEHOP._serialized_start=2856
  _TBALANCEHOP._serialized_end=2901
  _TBALANCETRACK._serialized_start=2903
  _TBALANCETRACK._serialized_end=2955
  _TBALANCETRACKLIST._serialized_start=2957
  _TBALANCETRACKLIST._serialized_end=3017
  _TREADSETDATA._serialized_start=3020
  _TREADSETDATA._serialized_end=3199
  _TREADSETDATA_EDECISION._serialized_start=3125
  _TREADSETDATA_EDECISION._serialized_end=3199
  _TEVREADSET._serialized_start=3202
  _TEVREADSET._serialized_end=3481
  _TEVREADSET_EFLAGS._serialized_start=3413
  _TEVREADSET_EFLAGS._serialized_end=3481
  _TEVREADSETACK._serialized_start=3484
  _TEVREADSETACK._serialized_end=3623
  _TKEYRANGE._serialized_start=3625
  _TKEYRANGE._serialized_end=3706
  _TEVSTREAMCLEARANCEREQUEST._serialized_start=3708
  _TEVSTREAMCLEARANCEREQUEST._serialized_end=3806
  _TEVSTREAMCLEARANCERESPONSE._serialized_start=3808
  _TEVSTREAMCLEARANCERESPONSE._serialized_end=3867
  _TEVSTREAMCLEARANCEPENDING._serialized_start=3869
  _TEVSTREAMCLEARANCEPENDING._serialized_end=3910
  _TEVSTREAMQUOTAREQUEST._serialized_start=3912
  _TEVSTREAMQUOTAREQUEST._serialized_end=3966
  _TEVSTREAMQUOTARESPONSE._serialized_start=3968
  _TEVSTREAMQUOTARESPONSE._serialized_end=4076
  _TEVSTREAMQUOTARELEASE._serialized_start=4078
  _TEVSTREAMQUOTARELEASE._serialized_end=4132
  _TEVSTREAMISDEAD._serialized_start=4134
  _TEVSTREAMISDEAD._serialized_end=4165
  _TEVINTERRUPTTRANSACTION._serialized_start=4167
  _TEVINTERRUPTTRANSACTION._serialized_end=4206
  _TEVSTREAMDATAACK._serialized_start=4208
  _TEVSTREAMDATAACK._serialized_end=4226
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ydb.core.protos import msgbus_kv_pb2 as ydb_dot_core_dot_protos_dot_msgbus__kv__pb2
from ydb.core.protos import msgbus_pb2 as ydb_dot_core_dot_protos_dot_msgbus__pb2
from ydb.core.protos import msgbus_pq_pb2 as ydb_dot_core_dot_protos_dot_msgbus__pq__pb2


class TGRpcServerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Request = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/Request',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.SchemeOperation = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/SchemeOperation',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TSchemeOperation.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.SchemeOperationStatus = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/SchemeOperationStatus',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TSchemeOperationStatus.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.SchemeDescribe = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/SchemeDescribe',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TSchemeDescribe.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.WhoAmI = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/WhoAmI',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TWhoAmI.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.LoginRequest = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/LoginRequest',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TLoginRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.ChooseProxy = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/ChooseProxy',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TChooseProxyRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.PersQueueRequest = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/PersQueueRequest',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pq__pb2.TPersQueueRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.SchemeInitRoot = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/SchemeInitRoot',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TSchemeInitRoot.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.BSAdm = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/BSAdm',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TBSAdm.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.ResolveNode = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/ResolveNode',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResolveNodeRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.FillNode = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/FillNode',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TFillNodeRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.DrainNode = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/DrainNode',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TDrainNodeRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.BlobStorageConfig = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/BlobStorageConfig',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TBlobStorageConfigRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.HiveCreateTablet = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/HiveCreateTablet',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.THiveCreateTablet.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.LocalEnumerateTablets = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/LocalEnumerateTablets',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TLocalEnumerateTablets.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.KeyValue = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/KeyValue',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__kv__pb2.TKeyValueRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.TestShardControl = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/TestShardControl',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TTestShardControlRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.RegisterNode = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/RegisterNode',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TNodeRegistrationRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TNodeRegistrationResponse.FromString,
                )
        self.CmsRequest = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/CmsRequest',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TCmsRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TCmsResponse.FromString,
                )
        self.SqsRequest = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/SqsRequest',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TSqsRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TSqsResponse.FromString,
                )
        self.ConsoleRequest = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/ConsoleRequest',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TConsoleRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TConsoleResponse.FromString,
                )
        self.LocalMKQL = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/LocalMKQL',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TLocalMKQL.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.LocalSchemeTx = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/LocalSchemeTx',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TLocalSchemeTx.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.TabletKillRequest = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/TabletKillRequest',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TTabletKillRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.InterconnectDebug = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/InterconnectDebug',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TInterconnectDebug.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.TabletStateRequest = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/TabletStateRequest',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TTabletStateRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.BlobStorageLoadRequest = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/BlobStorageLoadRequest',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TBsTestLoadRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.BlobStorageGetRequest = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/BlobStorageGetRequest',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TBsGetRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.DataShardLoadRequest = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/DataShardLoadRequest',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TDsTestLoadRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.DbSchema = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/DbSchema',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.FromString,
                )
        self.DbOperation = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/DbOperation',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.FromString,
                )
        self.DbBatch = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/DbBatch',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.FromString,
                )


class TGRpcServerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Request(self, request, context):
        """TODO
        * Rename Request to MiniKQLRequest ???

        ///////////////////////////////////////////////////////////////////////////////////////////////
        KIKIMR CLIENT INTERFACE
        ///////////////////////////////////////////////////////////////////////////////////////////////

        MiniKQL request (DML)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SchemeOperation(self, request, context):
        """DML transactions
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SchemeOperationStatus(self, request, context):
        """status polling for scheme transactions
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SchemeDescribe(self, request, context):
        """describe
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WhoAmI(self, request, context):
        """whoami
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LoginRequest(self, request, context):
        """login
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChooseProxy(self, request, context):
        """///////////////////////////////////////////////////////////////////////////////////////////////
        CHOOSE PROXY INTERFACE
        ///////////////////////////////////////////////////////////////////////////////////////////////
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PersQueueRequest(self, request, context):
        """///////////////////////////////////////////////////////////////////////////////////////////////
        PERSISTENT QUEUE CLIENT INTERFACE
        ///////////////////////////////////////////////////////////////////////////////////////////////

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SchemeInitRoot(self, request, context):
        """///////////////////////////////////////////////////////////////////////////////////////////////
        ADMIN INTERNAL INTERFACE
        ///////////////////////////////////////////////////////////////////////////////////////////////
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BSAdm(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResolveNode(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FillNode(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DrainNode(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BlobStorageConfig(self, request, context):
        """Blob storage configuration manipulation/query interface
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HiveCreateTablet(self, request, context):
        """///////////////////////////////////////////////////////////////////////////////////////////////
        KV-TABLET INTERNAL INTERFACE
        ///////////////////////////////////////////////////////////////////////////////////////////////
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LocalEnumerateTablets(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def KeyValue(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TestShardControl(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterNode(self, request, context):
        """///////////////////////////////////////////////////////////////////////////////////////////////
        DYNAMIC NODES INTERNAL INTERFACE
        ///////////////////////////////////////////////////////////////////////////////////////////////
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CmsRequest(self, request, context):
        """///////////////////////////////////////////////////////////////////////////////////////////////
        CMS INTERFACE
        ///////////////////////////////////////////////////////////////////////////////////////////////
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SqsRequest(self, request, context):
        """///////////////////////////////////////////////////////////////////////////////////////////////
        SQS INTERFACE
        ///////////////////////////////////////////////////////////////////////////////////////////////
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConsoleRequest(self, request, context):
        """///////////////////////////////////////////////////////////////////////////////////////////////
        CONSOLE INTERFACE
        ///////////////////////////////////////////////////////////////////////////////////////////////
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LocalMKQL(self, request, context):
        """///////////////////////////////////////////////////////////////////////////////////////////////
        INTROSPECTION
        ///////////////////////////////////////////////////////////////////////////////////////////////
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LocalSchemeTx(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TabletKillRequest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InterconnectDebug(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TabletStateRequest(self, request, context):
        """[DEPRECATED]
        rpc Navigate(TSchemeNavigate) returns (TResponse);

        ///////////////////////////////////////////////////////////////////////////////////////////////
        MONITORING
        ///////////////////////////////////////////////////////////////////////////////////////////////
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BlobStorageLoadRequest(self, request, context):
        """///////////////////////////////////////////////////////////////////////////////////////////////
        BLOBSTORAGE LOAD TEST
        ///////////////////////////////////////////////////////////////////////////////////////////////
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BlobStorageGetRequest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DataShardLoadRequest(self, request, context):
        """///////////////////////////////////////////////////////////////////////////////////////////////
        DATASHARD LOAD TEST
        ///////////////////////////////////////////////////////////////////////////////////////////////
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DbSchema(self, request, context):
        """///////////////////////////////////////////////////////////////////////////////////////////////
        HTTP INTERFACE
        ///////////////////////////////////////////////////////////////////////////////////////////////
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DbOperation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DbBatch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TGRpcServerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Request': grpc.unary_unary_rpc_method_handler(
                    servicer.Request,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'SchemeOperation': grpc.unary_unary_rpc_method_handler(
                    servicer.SchemeOperation,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TSchemeOperation.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'SchemeOperationStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.SchemeOperationStatus,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TSchemeOperationStatus.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'SchemeDescribe': grpc.unary_unary_rpc_method_handler(
                    servicer.SchemeDescribe,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TSchemeDescribe.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'WhoAmI': grpc.unary_unary_rpc_method_handler(
                    servicer.WhoAmI,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TWhoAmI.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'LoginRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.LoginRequest,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TLoginRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'ChooseProxy': grpc.unary_unary_rpc_method_handler(
                    servicer.ChooseProxy,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TChooseProxyRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'PersQueueRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.PersQueueRequest,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pq__pb2.TPersQueueRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'SchemeInitRoot': grpc.unary_unary_rpc_method_handler(
                    servicer.SchemeInitRoot,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TSchemeInitRoot.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'BSAdm': grpc.unary_unary_rpc_method_handler(
                    servicer.BSAdm,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TBSAdm.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'ResolveNode': grpc.unary_unary_rpc_method_handler(
                    servicer.ResolveNode,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResolveNodeRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'FillNode': grpc.unary_unary_rpc_method_handler(
                    servicer.FillNode,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TFillNodeRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'DrainNode': grpc.unary_unary_rpc_method_handler(
                    servicer.DrainNode,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TDrainNodeRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'BlobStorageConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.BlobStorageConfig,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TBlobStorageConfigRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'HiveCreateTablet': grpc.unary_unary_rpc_method_handler(
                    servicer.HiveCreateTablet,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.THiveCreateTablet.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'LocalEnumerateTablets': grpc.unary_unary_rpc_method_handler(
                    servicer.LocalEnumerateTablets,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TLocalEnumerateTablets.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'KeyValue': grpc.unary_unary_rpc_method_handler(
                    servicer.KeyValue,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__kv__pb2.TKeyValueRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'TestShardControl': grpc.unary_unary_rpc_method_handler(
                    servicer.TestShardControl,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TTestShardControlRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'RegisterNode': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterNode,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TNodeRegistrationRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TNodeRegistrationResponse.SerializeToString,
            ),
            'CmsRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.CmsRequest,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TCmsRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TCmsResponse.SerializeToString,
            ),
            'SqsRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.SqsRequest,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TSqsRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TSqsResponse.SerializeToString,
            ),
            'ConsoleRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.ConsoleRequest,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TConsoleRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TConsoleResponse.SerializeToString,
            ),
            'LocalMKQL': grpc.unary_unary_rpc_method_handler(
                    servicer.LocalMKQL,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TLocalMKQL.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'LocalSchemeTx': grpc.unary_unary_rpc_method_handler(
                    servicer.LocalSchemeTx,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TLocalSchemeTx.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'TabletKillRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.TabletKillRequest,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TTabletKillRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'InterconnectDebug': grpc.unary_unary_rpc_method_handler(
                    servicer.InterconnectDebug,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TInterconnectDebug.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'TabletStateRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.TabletStateRequest,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TTabletStateRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'BlobStorageLoadRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.BlobStorageLoadRequest,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TBsTestLoadRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'BlobStorageGetRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.BlobStorageGetRequest,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TBsGetRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'DataShardLoadRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.DataShardLoadRequest,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TDsTestLoadRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'DbSchema': grpc.unary_unary_rpc_method_handler(
                    servicer.DbSchema,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.SerializeToString,
            ),
            'DbOperation': grpc.unary_unary_rpc_method_handler(
                    servicer.DbOperation,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.SerializeToString,
            ),
            'DbBatch': grpc.unary_unary_rpc_method_handler(
                    servicer.DbBatch,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'NKikimrClient.TGRpcServer', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TGRpcServer(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Request(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/Request',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SchemeOperation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/SchemeOperation',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TSchemeOperation.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SchemeOperationStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/SchemeOperationStatus',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TSchemeOperationStatus.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SchemeDescribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/SchemeDescribe',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TSchemeDescribe.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WhoAmI(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/WhoAmI',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TWhoAmI.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LoginRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/LoginRequest',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TLoginRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChooseProxy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/ChooseProxy',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TChooseProxyRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PersQueueRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/PersQueueRequest',
            ydb_dot_core_dot_protos_dot_msgbus__pq__pb2.TPersQueueRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SchemeInitRoot(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/SchemeInitRoot',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TSchemeInitRoot.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BSAdm(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/BSAdm',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TBSAdm.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResolveNode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/ResolveNode',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResolveNodeRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FillNode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/FillNode',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TFillNodeRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DrainNode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/DrainNode',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TDrainNodeRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BlobStorageConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/BlobStorageConfig',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TBlobStorageConfigRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def HiveCreateTablet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/HiveCreateTablet',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.THiveCreateTablet.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LocalEnumerateTablets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/LocalEnumerateTablets',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TLocalEnumerateTablets.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def KeyValue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/KeyValue',
            ydb_dot_core_dot_protos_dot_msgbus__kv__pb2.TKeyValueRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TestShardControl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/TestShardControl',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TTestShardControlRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterNode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/RegisterNode',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TNodeRegistrationRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TNodeRegistrationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CmsRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/CmsRequest',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TCmsRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TCmsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SqsRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/SqsRequest',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TSqsRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TSqsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConsoleRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/ConsoleRequest',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TConsoleRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TConsoleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LocalMKQL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/LocalMKQL',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TLocalMKQL.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LocalSchemeTx(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/LocalSchemeTx',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TLocalSchemeTx.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TabletKillRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/TabletKillRequest',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TTabletKillRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InterconnectDebug(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/InterconnectDebug',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TInterconnectDebug.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TabletStateRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/TabletStateRequest',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TTabletStateRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BlobStorageLoadRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/BlobStorageLoadRequest',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TBsTestLoadRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BlobStorageGetRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/BlobStorageGetRequest',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TBsGetRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DataShardLoadRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/DataShardLoadRequest',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TDsTestLoadRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DbSchema(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/DbSchema',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DbOperation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/DbOperation',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DbBatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/DbBatch',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/counters.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eydb/core/protos/counters.proto\x12\x07NKikimr\x1a google/protobuf/descriptor.proto\"%\n\x06TRange\x12\r\n\x05Value\x18\x01 \x01(\x04\x12\x0c\n\x04Name\x18\x02 \x01(\t\"b\n\x0fTCounterOptions\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x1f\n\x06Ranges\x18\x02 \x03(\x0b\x32\x0f.NKikimr.TRange\x12\x10\n\x08Integral\x18\x03 \x01(\x08\x12\x0e\n\x06SVName\x18\x04 \x01(\t\"\x1e\n\x0eTTxTypeOptions\x12\x0c\n\x04Name\x18\x01 \x01(\t\"\xb7\x02\n\x16TLabeledCounterOptions\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12@\n\x08\x41ggrFunc\x18\x02 \x01(\x0e\x32..NKikimr.TLabeledCounterOptions.EAggregateFunc\x12\x45\n\x04Type\x18\x03 \x01(\x0e\x32,.NKikimr.TLabeledCounterOptions.ECounterType:\tCT_SIMPLE\x12\x10\n\x06SVName\x18\x04 \x01(\t:\x00\";\n\x0c\x45\x43ounterType\x12\r\n\tCT_SIMPLE\x10\x01\x12\x0e\n\nCT_TIMELAG\x10\x02\x12\x0c\n\x08\x43T_DERIV\x10\x03\"7\n\x0e\x45\x41ggregateFunc\x12\x0b\n\x07\x45\x41\x46_MAX\x10\x01\x12\x0b\n\x07\x45\x41\x46_MIN\x10\x02\x12\x0b\n\x07\x45\x41\x46_SUM\x10\x03\"1\n TLabeledCounterGroupNamesOptions\x12\r\n\x05Names\x18\x01 \x03(\t*5\n\x15\x45TxTypeSimpleCounters\x12\x1c\n\x18\x43OUNTER_TT_SIMPLE_IGNORE\x10\x00*\x82\x06\n\x19\x45TxTypeCumulativeCounters\x12 \n\x1c\x43OUNTER_TT_CULUMATIVE_IGNORE\x10\x00\x12)\n\x14\x43OUNTER_TT_POSTPONED\x10\x01\x1a\x0f\x82\xd6\x1b\x0b\n\tPostponed\x12.\n\x17\x43OUNTER_TT_RO_COMPLETED\x10\x02\x1a\x11\x82\xd6\x1b\r\n\x0bRoCompleted\x12.\n\x17\x43OUNTER_TT_RW_COMPLETED\x10\x03\x1a\x11\x82\xd6\x1b\r\n\x0bRwCompleted\x12#\n\x11\x43OUNTER_TT_WRITES\x10\x04\x1a\x0c\x82\xd6\x1b\x08\n\x06Writes\x12\x30\n\x18\x43OUNTER_TT_BYTES_WRITTEN\x10\x05\x1a\x12\x82\xd6\x1b\x0e\n\x0cWrittenBytes\x12*\n\x15\x43OUNTER_TT_BYTES_READ\x10\x06\x1a\x0f\x82\xd6\x1b\x0b\n\tReadBytes\x12\x34\n\x1a\x43OUNTER_TT_EXECUTE_CPUTIME\x10\x07\x1a\x14\x82\xd6\x1b\x10\n\x0e\x45xecuteCPUTime\x12<\n\x1e\x43OUNTER_TT_BOOKKEEPING_CPUTIME\x10\x08\x1a\x18\x82\xd6\x1b\x14\n\x12\x42ookkeepingCPUTime\x12\x36\n\x1b\x43OUNTER_TT_COMMITED_CPUTIME\x10\t\x1a\x15\x82\xd6\x1b\x11\n\x0f\x43ommitedCPUTime\x12\x32\n\x19\x43OUNTER_TT_TOUCHED_BLOCKS\x10\n\x1a\x13\x82\xd6\x1b\x0f\n\rTouchedBlocks\x12\x30\n\x18\x43OUNTER_TT_LOADED_BLOCKS\x10\x0b\x1a\x12\x82\xd6\x1b\x0e\n\x0cLoadedBlocks\x12+\n\x15\x43OUNTER_TT_TERMINATED\x10\x0c\x1a\x10\x82\xd6\x1b\x0c\n\nTerminated\x12\x39\n\x1d\x43OUNTER_TT_REDO_WRITTEN_BYTES\x10\r\x1a\x16\x82\xd6\x1b\x12\n\x10RedoWrittenBytes\x12;\n\x1e\x43OUNTER_TT_ANNEX_WRITTEN_BYTES\x10\x0e\x1a\x17\x82\xd6\x1b\x13\n\x11\x41nnexWrittenBytes*\x9b\x03\n\x19\x45TxTypePercentileCounters\x12 \n\x1c\x43OUNTER_TT_PERCENTILE_IGNORE\x10\x00\x1a\xdb\x02\x92\xd6\x1b\xd6\x02\x12\x11\x08\xf4\x03\x12\x0c(1) < 500 us\x12\x11\x08\xe8\x07\x12\x0c(2) 0.5-1 ms\x12\x0f\x08\xd0\x0f\x12\n(3) 1-2 ms\x12\x0f\x08\xa0\x1f\x12\n(4) 2-4 ms\x12\x0f\x08\xc0>\x12\n(5) 4-8 ms\x12\x10\x08\x80}\x12\x0b(6) 8-16 ms\x12\x12\x08\x80\xfa\x01\x12\x0c(7) 16-32 ms\x12\x12\x08\x80\xf4\x03\x12\x0c(8) 32-64 ms\x12\x13\x08\x80\xe8\x07\x12\r(9) 64-128 ms\x12\x15\x08\x80\xd0\x0f\x12\x0f(10) 128-256 ms\x12\x15\x08\x80\xa0\x1f\x12\x0f(11) 256-512 ms\x12\x16\x08\x80\xc0>\x12\x10(12) 512-1024 ms\x12\x17\x08\x80\x89z\x12\x11(13) 1024-2000 ms\x12\x11\x08\x80\x92\xf4\x01\x12\n(14) 2-4 s\x12\x11\x08\x80\xa4\xe8\x03\x12\n(15) 4-8 s\x12\x12\x08\x80\xc8\xd0\x07\x12\x0b(16) 8-16 s\x12\x13\x08\x80\x90\xa1\x0f\x12\x0c(17) 16-32 s:R\n\x0b\x43ounterOpts\x12!.google.protobuf.EnumValueOptions\x18\xe0\xba\x03 \x01(\x0b\x32\x18.NKikimr.TCounterOptions:P\n\nTxTypeOpts\x12!.google.protobuf.EnumValueOptions\x18\xe1\xba\x03 \x01(\x0b\x32\x17.NKikimr.TTxTypeOptions:`\n\x12LabeledCounterOpts\x12!.google.protobuf.EnumValueOptions\x18\xe4\xba\x03 \x01(\x0b\x32\x1f.NKikimr.TLabeledCounterOptions:S\n\x11GlobalCounterOpts\x12\x1c.google.protobuf.EnumOptions\x18\xe2\xba\x03 \x01(\x0b\x32\x18.NKikimr.TCounterOptions:g\n\x14GlobalGroupNamesOpts\x12\x1c.google.protobuf.EnumOptions\x18\xe5\xba\x03 \x01(\x0b\x32).NKikimr.TLabeledCounterGroupNamesOptions:6\n\x0eTabletTypeName\x12\x1c.google.protobuf.FileOptions\x18\xe3\xba\x03 \x01(\tB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.counters_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.EnumValueOptions.RegisterExtension(CounterOpts)
  google_dot_protobuf_dot_descriptor__pb2.EnumValueOptions.RegisterExtension(TxTypeOpts)
  google_dot_protobuf_dot_descriptor__pb2.EnumValueOptions.RegisterExtension(LabeledCounterOpts)
  google_dot_protobuf_dot_descriptor__pb2.EnumOptions.RegisterExtension(GlobalCounterOpts)
  google_dot_protobuf_dot_descriptor__pb2.EnumOptions.RegisterExtension(GlobalGroupNamesOpts)
  google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(TabletTypeName)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_POSTPONED"]._options = None
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_POSTPONED"]._serialized_options = b'\202\326\033\013\n\tPostponed'
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_RO_COMPLETED"]._options = None
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_RO_COMPLETED"]._serialized_options = b'\202\326\033\r\n\013RoCompleted'
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_RW_COMPLETED"]._options = None
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_RW_COMPLETED"]._serialized_options = b'\202\326\033\r\n\013RwCompleted'
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_WRITES"]._options = None
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_WRITES"]._serialized_options = b'\202\326\033\010\n\006Writes'
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_BYTES_WRITTEN"]._options = None
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_BYTES_WRITTEN"]._serialized_options = b'\202\326\033\016\n\014WrittenBytes'
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_BYTES_READ"]._options = None
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_BYTES_READ"]._serialized_options = b'\202\326\033\013\n\tReadBytes'
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_EXECUTE_CPUTIME"]._options = None
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_EXECUTE_CPUTIME"]._serialized_options = b'\202\326\033\020\n\016ExecuteCPUTime'
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_BOOKKEEPING_CPUTIME"]._options = None
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_BOOKKEEPING_CPUTIME"]._serialized_options = b'\202\326\033\024\n\022BookkeepingCPUTime'
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_COMMITED_CPUTIME"]._options = None
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_COMMITED_CPUTIME"]._serialized_options = b'\202\326\033\021\n\017CommitedCPUTime'
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_TOUCHED_BLOCKS"]._options = None
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_TOUCHED_BLOCKS"]._serialized_options = b'\202\326\033\017\n\rTouchedBlocks'
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_LOADED_BLOCKS"]._options = None
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_LOADED_BLOCKS"]._serialized_options = b'\202\326\033\016\n\014LoadedBlocks'
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_TERMINATED"]._options = None
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_TERMINATED"]._serialized_options = b'\202\326\033\014\n\nTerminated'
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_REDO_WRITTEN_BYTES"]._options = None
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_REDO_WRITTEN_BYTES"]._serialized_options = b'\202\326\033\022\n\020RedoWrittenBytes'
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_ANNEX_WRITTEN_BYTES"]._options = None
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_ANNEX_WRITTEN_BYTES"]._serialized_options = b'\202\326\033\023\n\021AnnexWrittenBytes'
  _ETXTYPEPERCENTILECOUNTERS._options = None
  _ETXTYPEPERCENTILECOUNTERS._serialized_options = b'\222\326\033\326\002\022\021\010\364\003\022\014(1) < 500 us\022\021\010\350\007\022\014(2) 0.5-1 ms\022\017\010\320\017\022\n(3) 1-2 ms\022\017\010\240\037\022\n(4) 2-4 ms\022\017\010\300>\022\n(5) 4-8 ms\022\020\010\200}\022\013(6) 8-16 ms\022\022\010\200\372\001\022\014(7) 16-32 ms\022\022\010\200\364\003\022\014(8) 32-64 ms\022\023\010\200\350\007\022\r(9) 64-128 ms\022\025\010\200\320\017\022\017(10) 128-256 ms\022\025\010\200\240\037\022\017(11) 256-512 ms\022\026\010\200\300>\022\020(12) 512-1024 ms\022\027\010\200\211z\022\021(13) 1024-2000 ms\022\021\010\200\222\364\001\022\n(14) 2-4 s\022\021\010\200\244\350\003\022\n(15) 4-8 s\022\022\010\200\310\320\007\022\013(16) 8-16 s\022\023\010\200\220\241\017\022\014(17) 16-32 s'
  _ETXTYPESIMPLECOUNTERS._serialized_start=613
  _ETXTYPESIMPLECOUNTERS._serialized_end=666
  _ETXTYPECUMULATIVECOUNTERS._serialized_start=669
  _ETXTYPECUMULATIVECOUNTERS._serialized_end=1439
  _ETXTYPEPERCENTILECOUNTERS._serialized_start=1442
  _ETXTYPEPERCENTILECOUNTERS._serialized_end=1853
  _TRANGE._serialized_start=77
  _TRANGE._serialized_end=114
  _TCOUNTEROPTIONS._serialized_start=116
  _TCOUNTEROPTIONS._serialized_end=214
  _TTXTYPEOPTIONS._serialized_start=216
  _TTXTYPEOPTIONS._serialized_end=246
  _TLABELEDCOUNTEROPTIONS._serialized_start=249
  _TLABELEDCOUNTEROPTIONS._serialized_end=560
  _TLABELEDCOUNTEROPTIONS_ECOUNTERTYPE._serialized_start=444
  _TLABELEDCOUNTEROPTIONS_ECOUNTERTYPE._serialized_end=503
  _TLABELEDCOUNTEROPTIONS_EAGGREGATEFUNC._serialized_start=505
  _TLABELEDCOUNTEROPTIONS_EAGGREGATEFUNC._serialized_end=560
  _TLABELEDCOUNTERGROUPNAMESOPTIONS._serialized_start=562
  _TLABELEDCOUNTERGROUPNAMESOPTIONS._serialized_end=611
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/export.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.public.api.protos import ydb_export_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__export__pb2
from ydb.public.api.protos import ydb_issue_message_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__issue__message__pb2
from ydb.public.api.protos import ydb_operation_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__operation__pb2
from ydb.public.api.protos import ydb_status_codes_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__status__codes__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cydb/core/protos/export.proto\x12\rNKikimrExport\x1a&ydb/public/api/protos/ydb_export.proto\x1a-ydb/public/api/protos/ydb_issue_message.proto\x1a)ydb/public/api/protos/ydb_operation.proto\x1a,ydb/public/api/protos/ydb_status_codes.proto\"\xdf\x02\n\x07TExport\x12\n\n\x02Id\x18\x01 \x01(\x04\x12)\n\x06Status\x18\x02 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x03 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x35\n\x08Progress\x18\x04 \x01(\x0e\x32#.Ydb.Export.ExportProgress.Progress\x12\x35\n\rItemsProgress\x18\x07 \x03(\x0b\x32\x1e.Ydb.Export.ExportItemProgress\x12<\n\x12\x45xportToYtSettings\x18\x05 \x01(\x0b\x32\x1e.Ydb.Export.ExportToYtSettingsH\x00\x12<\n\x12\x45xportToS3Settings\x18\x06 \x01(\x0b\x32\x1e.Ydb.Export.ExportToS3SettingsH\x00\x42\n\n\x08Settings\"\xd8\x01\n\x14TCreateExportRequest\x12\x38\n\x0fOperationParams\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12<\n\x12\x45xportToYtSettings\x18\x02 \x01(\x0b\x32\x1e.Ydb.Export.ExportToYtSettingsH\x00\x12<\n\x12\x45xportToS3Settings\x18\x03 \x01(\x0b\x32\x1e.Ydb.Export.ExportToS3SettingsH\x00\x42\n\n\x08Settings\"\x83\x01\n\x16TEvCreateExportRequest\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x14\n\x0c\x44\x61tabaseName\x18\x02 \x01(\t\x12\x0f\n\x07UserSID\x18\x04 \x01(\t\x12\x34\n\x07Request\x18\x03 \x01(\x0b\x32#.NKikimrExport.TCreateExportRequest\">\n\x15TCreateExportResponse\x12%\n\x05\x45ntry\x18\x01 \x01(\x0b\x32\x16.NKikimrExport.TExport\"_\n\x17TEvCreateExportResponse\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x36\n\x08Response\x18\x02 \x01(\x0b\x32$.NKikimrExport.TCreateExportResponse\"\x1f\n\x11TGetExportRequest\x12\n\n\x02Id\x18\x01 \x01(\x04\"^\n\x13TEvGetExportRequest\x12\x14\n\x0c\x44\x61tabaseName\x18\x02 \x01(\t\x12\x31\n\x07Request\x18\x01 \x01(\x0b\x32 .NKikimrExport.TGetExportRequest\";\n\x12TGetExportResponse\x12%\n\x05\x45ntry\x18\x01 \x01(\x0b\x32\x16.NKikimrExport.TExport\"K\n\x14TEvGetExportResponse\x12\x33\n\x08Response\x18\x01 \x01(\x0b\x32!.NKikimrExport.TGetExportResponse\"\"\n\x14TCancelExportRequest\x12\n\n\x02Id\x18\x01 \x01(\x04\"r\n\x16TEvCancelExportRequest\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x14\n\x0c\x44\x61tabaseName\x18\x03 \x01(\t\x12\x34\n\x07Request\x18\x02 \x01(\x0b\x32#.NKikimrExport.TCancelExportRequest\"k\n\x15TCancelExportResponse\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"_\n\x17TEvCancelExportResponse\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x36\n\x08Response\x18\x02 \x01(\x0b\x32$.NKikimrExport.TCancelExportResponse\"\"\n\x14TForgetExportRequest\x12\n\n\x02Id\x18\x01 \x01(\x04\"r\n\x16TEvForgetExportRequest\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x14\n\x0c\x44\x61tabaseName\x18\x03 \x01(\t\x12\x34\n\x07Request\x18\x02 \x01(\x0b\x32#.NKikimrExport.TForgetExportRequest\"k\n\x15TForgetExportResponse\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"_\n\x17TEvForgetExportResponse\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x36\n\x08Response\x18\x02 \x01(\x0b\x32$.NKikimrExport.TForgetExportResponse\"H\n\x13TListExportsRequest\x12\x10\n\x08PageSize\x18\x01 \x01(\x04\x12\x11\n\tPageToken\x18\x02 \x01(\t\x12\x0c\n\x04Kind\x18\x03 \x01(\t\"b\n\x15TEvListExportsRequest\x12\x14\n\x0c\x44\x61tabaseName\x18\x02 \x01(\t\x12\x33\n\x07Request\x18\x01 \x01(\x0b\x32\".NKikimrExport.TListExportsRequest\"\xaa\x01\n\x14TListExportsResponse\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\'\n\x07\x45ntries\x18\x03 \x03(\x0b\x32\x16.NKikimrExport.TExport\x12\x15\n\rNextPageToken\x18\x04 \x01(\t\"O\n\x16TEvListExportsResponse\x12\x35\n\x08Response\x18\x01 \x01(\x0b\x32#.NKikimrExport.TListExportsResponseB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.export_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TEXPORT._serialized_start=224
  _TEXPORT._serialized_end=575
  _TCREATEEXPORTREQUEST._serialized_start=578
  _TCREATEEXPORTREQUEST._serialized_end=794
  _TEVCREATEEXPORTREQUEST._serialized_start=797
  _TEVCREATEEXPORTREQUEST._serialized_end=928
  _TCREATEEXPORTRESPONSE._serialized_start=930
  _TCREATEEXPORTRESPONSE._serialized_end=992
  _TEVCREATEEXPORTRESPONSE._serialized_start=994
  _TEVCREATEEXPORTRESPONSE._serialized_end=1089
  _TGETEXPORTREQUEST._serialized_start=1091
  _TGETEXPORTREQUEST._serialized_end=1122
  _TEVGETEXPORTREQUEST._serialized_start=1124
  _TEVGETEXPORTREQUEST._serialized_end=1218
  _TGETEXPORTRESPONSE._serialized_start=1220
  _TGETEXPORTRESPONSE._serialized_end=1279
  _TEVGETEXPORTRESPONSE._serialized_start=1281
  _TEVGETEXPORTRESPONSE._serialized_end=1356
  _TCANCELEXPORTREQUEST._serialized_start=1358
  _TCANCELEXPORTREQUEST._serialized_end=1392
  _TEVCANCELEXPORTREQUEST._serialized_start=1394
  _TEVCANCELEXPORTREQUEST._serialized_end=1508
  _TCANCELEXPORTRESPONSE._serialized_start=1510
  _TCANCELEXPORTRESPONSE._serialized_end=1617
  _TEVCANCELEXPORTRESPONSE._serialized_start=1619
  _TEVCANCELEXPORTRESPONSE._serialized_end=1714
  _TFORGETEXPORTREQUEST._serialized_start=1716
  _TFORGETEXPORTREQUEST._serialized_end=1750
  _TEVFORGETEXPORTREQUEST._serialized_start=1752
  _TEVFORGETEXPORTREQUEST._serialized_end=1866
  _TFORGETEXPORTRESPONSE._serialized_start=1868
  _TFORGETEXPORTRESPONSE._serialized_end=1975
  _TEVFORGETEXPORTRESPONSE._serialized_start=1977
  _TEVFORGETEXPORTRESPONSE._serialized_end=2072
  _TLISTEXPORTSREQUEST._serialized_start=2074
  _TLISTEXPORTSREQUEST._serialized_end=2146
  _TEVLISTEXPORTSREQUEST._serialized_start=2148
  _TEVLISTEXPORTSREQUEST._serialized_end=2246
  _TLISTEXPORTSRESPONSE._serialized_start=2249
  _TLISTEXPORTSRESPONSE._serialized_end=2419
  _TEVLISTEXPORTSRESPONSE._serialized_start=2421
  _TEVLISTEXPORTSRESPONSE._serialized_end=2500
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/login/protos/login.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$ydb/library/login/protos/login.proto\x12\x0bNLoginProto\"O\n\nTPublicKey\x12\r\n\x05KeyId\x18\x01 \x01(\x04\x12\x14\n\nKeyDataPEM\x18\x02 \x01(\tH\x00\x12\x11\n\tExpiresAt\x18\t \x01(\x04\x42\t\n\x07KeyData\"7\n\x08\x45SidType\"+\n\x07SidType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04USER\x10\x01\x12\t\n\x05GROUP\x10\x02\"`\n\x04TSid\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12+\n\x04Type\x18\x02 \x01(\x0e\x32\x1d.NLoginProto.ESidType.SidType\x12\x0c\n\x04Hash\x18\x03 \x01(\t\x12\x0f\n\x07Members\x18\x04 \x03(\t\"p\n\x0eTSecurityState\x12+\n\nPublicKeys\x18\x01 \x03(\x0b\x32\x17.NLoginProto.TPublicKey\x12\x1f\n\x04Sids\x18\x02 \x03(\x0b\x32\x11.NLoginProto.TSid\x12\x10\n\x08\x41udience\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.login.protos.login_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TPUBLICKEY._serialized_start=53
  _TPUBLICKEY._serialized_end=132
  _ESIDTYPE._serialized_start=134
  _ESIDTYPE._serialized_end=189
  _ESIDTYPE_SIDTYPE._serialized_start=146
  _ESIDTYPE_SIDTYPE._serialized_end=189
  _TSID._serialized_start=191
  _TSID._serialized_end=287
  _TSECURITYSTATE._serialized_start=289
  _TSECURITYSTATE._serialized_end=401
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/yq/libs/config/protos/storage.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,ydb/core/yq/libs/config/protos/storage.proto\x12\x0bNYq.NConfig\"\xaf\x02\n\x11TYdbStorageConfig\x12\x10\n\x08\x45ndpoint\x18\x01 \x01(\t\x12\x10\n\x08\x44\x61tabase\x18\x02 \x01(\t\x12\x11\n\tOAuthFile\x18\x03 \x01(\t\x12\x13\n\x0bTablePrefix\x18\x04 \x01(\t\x12\x17\n\x0f\x43\x65rtificateFile\x18\x06 \x01(\t\x12\x13\n\x0bIamEndpoint\x18\x07 \x01(\t\x12\x11\n\tSaKeyFile\x18\x08 \x01(\t\x12\x1f\n\x17UseLocalMetadataService\x18\t \x01(\x08\x12\x18\n\x10\x43lientTimeoutSec\x18\n \x01(\r\x12\x1b\n\x13OperationTimeoutSec\x18\x0b \x01(\r\x12\x16\n\x0e\x43\x61ncelAfterSec\x18\x0c \x01(\r\x12\x0e\n\x06UseSsl\x18\r \x01(\x08\x12\r\n\x05Token\x18\x05 \x01(\tB\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.yq.libs.config.protos.storage_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TYDBSTORAGECONFIG._serialized_start=62
  _TYDBSTORAGECONFIG._serialized_end=365
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/folder_service/proto/folder_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5ydb/library/folder_service/proto/folder_service.proto\x12\x1bNKikimrProto.NFolderService\x1a\x1fgoogle/protobuf/timestamp.proto\"\x84\x03\n\x06\x46older\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x63loud_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12?\n\x06labels\x18\x06 \x03(\x0b\x32/.NKikimrProto.NFolderService.Folder.LabelsEntry\x12:\n\x06status\x18\x07 \x01(\x0e\x32*.NKikimrProto.NFolderService.Folder.Status\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"]\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x0c\n\x08\x44\x45LETING\x10\x02\x12\x0b\n\x07\x44\x45LETED\x10\x03\x12\x14\n\x10PENDING_DELETION\x10\x04\"%\n\x10GetFolderRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\"H\n\x11GetFolderResponse\x12\x33\n\x06\x66older\x18\x01 \x01(\x0b\x32#.NKikimrProto.NFolderService.Folderb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.folder_service.proto.folder_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FOLDER_LABELSENTRY._options = None
  _FOLDER_LABELSENTRY._serialized_options = b'8\001'
  _FOLDER._serialized_start=120
  _FOLDER._serialized_end=508
  _FOLDER_LABELSENTRY._serialized_start=368
  _FOLDER_LABELSENTRY._serialized_end=413
  _FOLDER_STATUS._serialized_start=415
  _FOLDER_STATUS._serialized_end=508
  _GETFOLDERREQUEST._serialized_start=510
  _GETFOLDERREQUEST._serialized_end=547
  _GETFOLDERRESPONSE._serialized_start=549
  _GETFOLDERRESPONSE._serialized_end=621
# @@protoc_insertion_point(module_scope)
